<meta property="og:image" content="https://www.open.ac.uk/ouheaders/gui/Open_University_OG_Image.png">
<meta property="og:image:alt" content="The Open University">
<meta property="twitter:image" content="https://www.open.ac.uk/ouheaders/gui/Open_University_OG_Image.png">
<meta property="og:title" content="The Open University"><!-- ou-head v2.0.0.542 -->

<!-- Stylesheets -->
<link rel="stylesheet" type="text/css" href="{{ content_root }}ouheaders/gui/headerfooter.css?2.0.0.542" media="screen">

<!--[if lt IE 9]><link rel="stylesheet" href="/ouheaders/gui/header-footer-ie.css" /><![endif]-->
<link rel="stylesheet" href="{{ content_root }}ouheaders/gui/headerfooter-print.css?2.0.0.542" media="print">

<!-- Stylesheets For cassie cookie widget -->
<link rel="stylesheet" type="text/css" href="{{ content_root }}ouheaders/gui/cassiecookiewidget.css?2.0.0.542"
    media="screen">
<!-- End of Stylesheets For cassie cookie widget -->

<!-- End ou-head v2.0.0.542 -->
