body .ou-cookies-bar,
body #ou-header,
body .ou-footer {
    font-size: 16px;
}
.ou-cookies-bar h3
{
    margin-top: .8em;
}
#ou-header #ou-service-links ul li
{
    *display: inline; /*For IE 7*/
}
body .ou-footer {
    font-size: 14px;
}
body .ou-footer a {
    font-size: 1.025em;
}
body .ou-footer .ou-contact {
    width: 78%;
    padding-top: 1.75em;
}
body .ou-footer .ou-contact,
body .ou-footer .ou-footer-nav #ou-ia-public,
body .ou-footer .ou-footer-nav #ou-ia-student,
body .ou-footer .ou-small-print {
    margin-left: 160px;
}
body .ou-footer .ou-footer-nav #ou-ia-public,
body .ou-footer .ou-footer-nav #ou-ia-student {
    margin-bottom: 25px;
}
body .ou-footer .ou-small-print {
    padding-left: 0;
    *clear: both; /*For IE 7*/
}
body .ou-footer .ou-footer-nav ul li a {
    padding-left: 0;
    padding-right: 30px;
}
/*IE7 only styles*/
#ou-header a.ou-logo {
  *position: relative;
}
body .ou-footer .ou-footer-nav #ou-ia-student ul.ou-inline li a span {
  *position:relative;
}
#ou-header #ou-service-links .ou-search {
  border: 1px solid #bfbfbf;
}
#ou-header #ou-service-links .ou-search:hover {
  border-color: rgba(0, 0, 0, 0.4);
}
#ou-header #ou-service-links .ou-search input.ou-header-search {
  *width: 70%;
  *float: left;
}
#ou-header #ou-service-links .ou-search .ou-button-container {
  *position: relative;
  *padding: 0;
  *margin: .5em 0 0 0;
  *height: 18px;
}
#ou-header #ou-service-links .ou-search .ou-button-container button {
  *top: 0;
}
body .ou-footer .ou-small-print .ou-copyright small {
  *clear: both;
}
body .ou-footer .ou-footer-title {
  *margin-left: 160px;
}