// =============================================================================
// Variables and Imports
//
// If you have a base partial (or equivalent), you should move these lines to
// =============================================================================

// Set this to true to force CSS output to exactly match normalize.css.
@strict-normalize: true;

// The default font family.
@base-font-family:   			Arial, Helvetica, sans-serif; //"futura-pt", verdana, sans-serif;
@secondary-font-family: 		Arial, Helvetica, sans-serif; //"CaratReg", "Book Antiqua", Georgia, serif;
@tertiary-font-family: 			Arial, Helvetica, sans-serif; //"CaratLight", "Book Antiqua", Georgia, serif;

// The base font size.
@base-font-size-legacy: 14px;
@base-font-size: 0.875rem; //updated from 1em
@base-font-size-calc: 0.875em; //updated from 1em

// The base line height determines the basic unit of vertical rhythm.
@base-line-height: 1.5;

// The font sizes for h1-h6.
@h1-font-size: 3.18367   * @base-font-size-calc; //equivilent to 39px
@h2-font-size: 2.20408   * @base-font-size-calc; //equivilent to 27px
@h3-font-size: 1.55102   * @base-font-size-calc; //equivilent to 19px
@h4-font-size: 1.387754  * @base-font-size-calc; //equivilent to 17px
@h5-font-size: 1.22449   * @base-font-size-calc; //equivilent to 15px
@h6-font-size: 1.14286   * @base-font-size-calc; //equivilent to 14px

// The amount lists and blockquotes are indented.
@indent-amount: 2.5em;

// Set this to true to add support for IE 6.
@legacy-support-for-ie6: false;

// Set this to true to add support for IE 7.
@legacy-support-for-ie7: true;
