@import "variables.less";
@import "mixins.less";
@import "base.less";
// Default

#ou-head #ou-header a.ou-logo {
    float: left;
    display: block;
    margin: 20px 0 0 0;
    //height: 61px;
    //width: 87px;
    //For SVG files
    height: 58px;
    width: 178.5px;
    background-size: 178.5px 58px;
    /*//For png img
    height: 58px;
    width: 180px;
    background-size: 218.5px 108px;
    background-position: center;
    //For png img*/
    background-image: url('/ouheaders/gui/OU_Logo.svg?2.0.0.542');
    position: relative;
    overflow: hidden;

    &:focus-visible {
        outline: 2px solid #FDF289;
        padding: 1px;
        border-radius:2px;
    }

    img {
        border: 0;
        top: 0px;
        position: relative;
        //width: 258px;
        visibility: hidden;
    }
}

// Display correct logo based on nation

// England

#ou-head #ou-header {
    a.ou-logo.england {
        display: block;
        visibility: visible;
    }

    a.ou-logo.international,
    a.ou-logo.scotland,
    a.ou-logo.nir,
    a.ou-logo.roi,
    a.ou-logo.wales,
    a.ou-logo.cymraeg,
    a.ou-logo.nonav {
        .visibilityHidden();
    }
}

// Scotland
.scotland {
    #ou-head #ou-header {
        a.ou-logo.scotland {
            &:extend(#ou-head #ou-header a.ou-logo.england);

            img {
                // top: -68px;
                position: relative;
                visibility: hidden;
            }
        }

        a.ou-logo.england,
        a.ou-logo.nir,
        a.ou-logo.roi,
        a.ou-logo.wales,
        a.ou-logo.cymraeg,
        a.ou-logo.nonav {
            &:extend(#ou-head #ou-header a.ou-logo.scotland);
        }
    }
}
.scotland #ou-head #ou-header a.ou-logo {
    //background-position: 0 -364px;
    //width: 83px;
    //height: 76px;
    height: 58px;
    width: 136.5px;
    background-image: url('/ouheaders/gui/OU_Logo_Scotland.svg?2.0.0.542');
    background-size: 136.5px 58px;
    position: relative;
}

// Wales
.wales {
    #ou-head #ou-header {
        a.ou-logo.wales {
            &:extend(#ou-head #ou-header a.ou-logo.england);

            img {
                //top: -149px;
                position: relative;
                visibility: hidden;
            }
        }

        a.ou-logo.england,
        a.ou-logo.scotland,
        a.ou-logo.nir,
        a.ou-logo.roi,
        a.ou-logo.cymraeg,
        a.ou-logo.nonav {
            &:extend(#ou-head #ou-header a.ou-logo.scotland);
        }
    }
}

.cymraeg {
    #ou-head #ou-header {
        a.ou-logo.cymraeg {
            &:extend(#ou-head #ou-header a.ou-logo.england);

            img {
                //top: -149px;
                position: relative;
            }
        }

        a.ou-logo.england,
        a.ou-logo.scotland,
        a.ou-logo.nir,
        a.ou-logo.roi,
        a.ou-logo.wales,
        a.ou-logo.nonav {
            &:extend(#ou-head #ou-header a.ou-logo.scotland);
        }
    }
}

.wales #ou-head #ou-header a.ou-logo,
.cymraeg #ou-head #ou-header a.ou-logo {
    //background-position: 0 -150px;
    //width: 107px;
    //height: 79px;
    height: 58px;
    width: 162.5px;
    background-image: url('/ouheaders/gui/OU_Logo_Wales.svg?2.0.0.542');
    background-size: 162.5px 58px;
    position: relative;
}

// Republic of Ireland
.roi {
    #ou-head #ou-header {
        a.ou-logo.roi {
            &:extend(#ou-head #ou-header a.ou-logo.england);

            img {
                // top: -320px;
                //left: -176px;
                position: relative;
            }
        }

        a.ou-logo.england,
        a.ou-logo.scotland,
        a.ou-logo.nir,
        a.ou-logo.wales,
        a.ou-logo.cymraeg,
        a.ou-logo.nonav {
            &:extend(#ou-head #ou-header a.ou-logo.scotland);
        }
    }
}
.roi #ou-head #ou-header a.ou-logo {
    //background-position: -176px -320px;
    //width: 83px;
    // height: 75px;
    height: 58px;
    width: 136.5px;
    background-image: url('/ouheaders/gui/OU_Logo_Ireland.svg?2.0.0.542');
    background-size: 136.5px 58px;
    position: relative;
}

// Northern Ireland
.nir {
    #ou-head #ou-header {
        a.ou-logo.nir {
            &:extend(#ou-head #ou-header a.ou-logo.england);
        }

        a.ou-logo.england,
        a.ou-logo.scotland,
        a.ou-logo.roi,
        a.ou-logo.wales,
        a.ou-logo.cymraeg,
        a.ou-logo.nonav {
            &:extend(#ou-head #ou-header a.ou-logo.scotland);
        }
    }
}

// No Navigation
.ou-ia-nonav {
    #ou-head #ou-header {
        a.ou-logo.nonav {
            &:extend(#ou-head #ou-header a.ou-logo.england);
            cursor: default;
        }

        a.ou-logo.england,
        a.ou-logo.scotland,
        a.ou-logo.nir,
        a.ou-logo.roi,
        a.ou-logo.wales,
        a.ou-logo.cymraeg {
            &:extend(#ou-head #ou-header a.ou-logo.scotland);
        }
    }
}

// International Student variation
.ou-ia-international {
    #ou-head #ou-header {
        a.ou-logo.international {
            &:extend(#ou-head #ou-header a.ou-logo.england);
        }

        a.ou-logo.england,
        a.ou-logo.nir,
        a.ou-logo.roi,
        a.ou-logo.wales,
        a.ou-logo.cymraeg,
        a.ou-logo.scotland,
        a.ou-logo.nonav {
            &:extend(#ou-head #ou-header a.ou-logo.scotland);
        }
    }
}
