// =============================================================================// Fonts

// Carat Regular
@font-face {
	font-family: 'CaratReg';
	src: url('/ouheaders/gui/fonts/carat-reg/2A86BB_0_0.eot');
	src: url('/ouheaders/gui/fonts/carat-reg/2A86BB_0_0.eot?#iefix') format('embedded-opentype'),
		 url('/ouheaders/gui/fonts/carat-reg/2A86BB_0_0.woff') format('woff'),
		 url('/ouheaders/gui/fonts/carat-reg/2A86BB_0_0.ttf') format('truetype');
    font-weight: normal;
	font-style: normal;
}
// Futura PT
@font-face {
	font-family: 'futura-pt';
	src: url('/ouheaders/gui/fonts/futura-pt/FTN45__W.eot');
	src: url('/ouheaders/gui/fonts/futura-pt/FTN45__W.eot?#iefix') format('embedded-opentype'),
		 url('/ouheaders/gui/fonts/futura-pt/FTN45__W.woff') format('woff'),
	     url('/ouheaders/gui/fonts/futura-pt/FTN45__W.ttf') format('truetype'),
	     url('/ouheaders/gui/fonts/futura-pt/FTN45__W.svg#futura-pt') format('svg');
	font-weight: normal;
	font-style: normal;
}
// Font Awesome
@font-face {
    font-family: 'FontAwesome';
    src: url('/ouheaders/gui/fonts/fontawesome/fontawesome-webfont.eot');
    src: url('/ouheaders/gui/fonts/fontawesome/fontawesome-webfont.eot') format('embedded-opentype'),
         url('/ouheaders/gui/fonts/fontawesome/fontawesome-webfont.woff') format('woff'),
         url('/ouheaders/gui/fonts/fontawesome/fontawesome-webfont.ttf') format('truetype'),
         url('/ouheaders/gui/fonts/fontawesome/fontawesome-webfont.svg') format('svg');
    font-weight: normal;
    font-style: normal;
}