//fonts
@baseFont: Arial, Helvetica, sans-serif; //"futura-pt", verdana, sans-serif;
@baseFontSize: 1em;

// colours

@white: #fff;
@black: #000;

// Rebrand colours names directly reference the same names
// as those specified within OU Digital.

@pink: #e21481;
@pinkLighter1: #e63794;
@pinkDarker2: #b51067;

@beigeLighter6:         #f8f6ed;

@purpleDarker4:         #44436b;

@blue:                  #0e56a7;
@blueLighter1:          #326fb4;
@blueLighter7:          #eef3f9;
@brightBlueLighter6:    #d8e6ef;

@turquoiseLighter7:     #eef6f7;

@blackLighter2:         #4d4d4d;
@blackLighter3:         #737373;
@blackLighter5:         #bfbfbf;
@text-color:            #414042;

// Custom colour
@blueCustomLight1:      mix(@white, @blue, 90%);
@hoverColor:          rgba(0, 0, 0, 0.4);

@blueLighterForSearchBoxFocus : #EDF2F9;
@textColorForSearchBoxFocus: #697069;
@textColorForSearchBoxBlackLighter3: #767676;