/* Generated by ParaType (http://www.paratype.com)*/
/* Font Futura PT Heavy: Copyright � ParaType, 2012. All rights reserved.*/


@font-face {
	font-family: 'FuturaPTWebHeavyObl';
	src: url('FTN76__W.eot');
	src: local('Futura PT Web Heavy Oblique'), local('FuturaPTWebHeavyObl'),
	     url('FTN76__W.eot?#iefix') format('embedded-opentype'),
	     url('FTN76__W.woff') format('woff'),
	     url('FTN76__W.ttf') format('truetype'),
	     url('FTN76__W.svg#FuturaPTWeb-HeavyObl') format('svg');
	font-weight: normal;
	font-style: normal;
}