@import "mixins.less";

.ou-cookies-bar,
#ou-header,
#ou-org-footer {
    .ou-container {
	    width:100%;
	    padding:0 15px;
	    margin:0 auto;
	    max-width: 1180px;
    }
    .ou-row:before,
    .ou-row:after,
    .int-wrap:before,
    .int-wrap:after,
    .int-innerFeature:before,
    .int-innerFeature:after,
    .int-formFeature:before,
    .int-formFeature:after,
    .int-togglerFeature:before,
    .int-togglerFeature:after,
    .int-togglerFeatureNote:before,
    .int-togglerFeatureNote:after
    {
	    display: table;
	    line-height: 0;
	    content: "";
    }
    .ou-row:after,
    .int-wrap:after,
    .int-innerFeature:after,
    .int-formFeature:after,
    .int-togglerFeature:after,
    .int-togglerFeatureNote:after
    {
	    clear: both;
    }
    [class*="ou-grid"],
    [class*="int-col"]
    {
	    float: left;
	    display: block;
	    width: 100%;
	    margin-left: 2%;
	    position:relative;
        .boxSizing();
    }
    [class*="ou-grid"]:first-child,
    [class*="ou-grid"] .ou-grid,
    [class*="int-col"]:first-child
    {
	    margin-left: 0;
    }
    .ou-grid12,
    [class*="of2"] .ou-grid6,
    [class*="of3"] .ou-grid4,
    [class*="1/3rd"] .ou-grid4,
    [class*="2/3rd"] .ou-grid8
    {
	    width: 100%;
	    margin-left: 0;
    }
    .ou-grid11
    {
	    width: 91.5%;
    }
    [class*="2/3rd"] .ou-grid7
    {
        width: 87.25%;
    }
    .ou-grid10,
    [class*="of2"] .ou-grid5
    {
	    width: 83%;
    }
    .ou-grid9,
    [class*="of3"] .ou-grid3,
    [class*="1/3rd"] .ou-grid3,
    [class*="2/3rd"] .ou-grid6
    {
	    width: 74.5%;
    }
    .ou-grid8,
    [class*="of2"] .ou-grid4,
    [class*="2/3rd"]
    {
	    width: 66%;
    }
    [class*="2/3rd"] .ou-grid5
    {
        width: 61.75%;
    }
    .ou-grid7
    {
	    width: 57.5%;
    }
    .ou-grid6,
    [class*="of2"],
    [class*="of2"] .ou-grid3,
    [class*="of3"] .ou-grid2,
    [class*="1/3rd"] .ou-grid2,
    [class*="2/3rd"] .ou-grid4
    {
	    width: 49%;
    }
    .ou-grid5
    {
	    width: 40.5%;
    }
    [class*="2/3rd"] .ou-grid3
    {
        width: 36.25%;
    }
    .ou-grid4,
    [class*="of2"] .ou-grid2,
    [class*="of3"],
    [class*="1/3rd"]
    {
	    width: 32%;
    }
    .ou-grid3,
    [class*="of3"] .ou-grid1,
    [class*="1/3rd"] .ou-grid1,
    [class*="2/3rd"] .ou-grid2
    {
	    width: 23.5%;
    }
    .ou-grid2,
    [class*="of2"] .ou-grid1
    {
	    width: 15%;
    }
    [class*="2/3rd"] .ou-grid1
    {
        width: 10.75%;
    }
    .ou-grid1
    {
	    width: 6.5%;
    }
    @media (max-width: 767px) {

	    [class*="ou-grid"] {
		    width: 100%;
		    margin-left: 0;
	    }
	    [class*="col"],
	    [class*="/3rd"],
	    [class*="col"] [class*="ou-grid"]
	    {
		    width: 100%;
		    margin-left: 0;
	    }
	    [class*="of2"],
	    .int-col3of3 {
		    margin-left: 0;
	    }
    }
}

@media (max-width: 767px) {
  #ou-header, #ou-org-footer {
	  [class*="ou-grid"] {
		  width: 100%;
		  margin-left: 0;
	  }
	  [class*="col"],
	  [class*="/3rd"],
	  [class*="col"] [class*="ou-grid"]
	  {
		  width: 100%;
		  margin-left: 0;
	  }
	  [class*="of2"],
	  .int-col3of3 {
		  margin-left: 0;
	  }
	}

}
