:root {
    --prebanner-secondary-color: #4f4f50;
    --prebanner-accept-all-button-color: #dc2587;
    --prebanner-accept-all-button-text-color: #fff;
    --prebanner-reject-all-button-color: #fff;
    --prebanner-reject-all-button-text-color: #2e2e37;
    --prebanner-customise-all-button-color: #2e2e37;
    --prebanner-customise-all-button-text-color: #fff;
    --banner-background-color: #2e2e37;
    --banner-secondary-color: #4f4f50;
    --banner-text-color: #fff;
    --banner-submit-preferences-button-color: #E21481;
    --banner-submit-preferences-button-text-color: #fff;
    --banner-slider-background-off: #4f4f50;
    --banner-slider-background-on: #e31f26;
    --banner-slider-toggle: #fff;
    --prebanner-background-color: #fff;
    --prebanner-border-color: #707070;
    --prebanner-text-color: #000;
    --accept-all-button-background-color: #3A3381;
    --accept-all-button-border-color: #3A3381;
    --accept-all-button-text-color: #fff;
    --reject-all-button-background-color: #3A3381;
    --reject-all-button-border-color: #3A3381;
    --reject-all-button-text-color: #fff;
    --view-all-button-background-color: #FFFFFF;
    --view-all-button-border-color: #fff;
    --view-all-button-text-color: #24285C;
    --view-all-button-icon-color: #fff;
    --cookie-modal-background-color: #fff;
    --cookie-modal-border-color: #707070;
    --cookie-modal-text-color: #000;
    --close-modal-button-color: #4f4f50;
    --header-content-top-border-color: #4f4f50;
    --main-content-border-colour: #4f4f50;
    --tab-button-background-color: #4f4f50;
    --tab-button-text-color: #fff;
    --tab-button-border-color: #4f4f50;
    --active-button-border-color: #fff;
    --cookie-group-bottom-border-colour: #0E56A7;
    --expand-cookies-icon-color: #e31f26;
    --cookie-children-container-background-color: #fff;
    --cookie-children-container-text-color: #4f4f50;
    --save-preferences-button-background-color: #3A3381;
    --save-preferences-button-text-color: #fff;
    --save-preferences-button-border-color: #3A3381;
    --scrollbar-background-color: #fff;
    --scrollbar-thumb-color: #326FB4;
    --scrollbar-thumb-hover-color: #004098;
    --slider-background-colour-unchecked: #E9EAEA;
    --toggle-background-color: #1F55A5;
    --slider-background-color-checked: #E9EEF6;
    --manage-cookies-button-background-color: #2e2e37;
    --manage-cookies-button-text-color: #fff;
    --manage-cookies-button-border-color: #e31f26
}

.cassie-widget {
    display: none
}

.cassie-cookie-module > .cassie-pre-banner {
    flex-direction: column;
    border-radius: 0px;
}

.cassie-pre-banner p {
    font: normal normal normal 17px/26px Arial;
    color: #24285C;
}

.cassie-cookie-module {
    align-items: center;
    display: flex;
    font-weight: 100;
    height: 100%;
    margin: 0;
    position: absolute;
    width: 100%
}

.cassie-cookie-module, .cassie-cookie-module button {
    font-family: Averta,sans-serif
}

.cassie-cookie-module > .cassie-overlay {
    background-color: rgba(0,0,0,.7);
    bottom: 0;
    height: 100%;
    left: 0;
    position: fixed;
    right: 0;
    top: 0;
    width: 100%;
    z-index: 999
}

.cassie-cookie-module > .cassie-pre-banner {
    align-self: flex-start;
    background-color: var(--prebanner-background-color);
    border-color: var(--prebanner-accept-all-button-color);
    border-bottom-color: var(--prebanner-border-color);
    border-left: 1px solid;
    border-left-color: var(--prebanner-border-color);
    border-right: 1px solid;
    border-right-color: var(--prebanner-border-color);
    border-top-color: var(--prebanner-border-color);
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    margin: 10px;
    position: relative;
    max-width: 90%;
    width: fit-content;
    z-index: 9999;
    margin: auto;
    padding: 20px 0px;
}

.cassie-pre-banner--text > h2 {
    opacity: 1;
    width: fit-content;
    text-align: left;
    font: normal normal normal 30px/40px Arial;
    letter-spacing: 0px;
    font: normal normal normal 39px/46px Arial;
    color: #24285C;
}


.cassie-pre-banner > .cassie-pre-banner--text {
    color: var(--prebanner-text-color);
    font: normal normal normal 17px/26px Arial;
    line-height: 1.6;
    padding: 0px 30px;
    width: fit-content;
    margin-top: 0px;
}

.cassie-pre-banner .cassie-pre-banner--button--container {
    margin: 0 30px 15px;
    width: 90%;
    margin-right:2%;
}

.cassie-pre-banner--button--container .cassie-pre-banner--button {
    border-radius: 27px;
    cursor: pointer;
    font: normal normal normal 16px/18px Arial;
    margin: 10px;
    overflow-wrap: break-word;
    max-width: 100%;
    width: 55%;
}

.cassie-pre-banner--button--container .cassie-pre-banner--button:focus {
    background: #FDF289;
    border: 2px solid #000;
    color: #000000;
}

.cassie-pre-banner--button--container .cassie-pre-banner--button:active {
    background: #28245A;
    box-shadow: inset 0px 5px 6px rgba(255,255,255,0.3);
    border: 2px solid #29245A;
    color: #FFFFFF;
}


.cassie-pre-banner .cassie-accept-all {
    background-color: var(--accept-all-button-background-color);
    border: 2px solid var(--accept-all-button-border-color);
    color: var(--accept-all-button-text-color);
    width: 168px;
    height: 47px;
}

.cassie-pre-banner .cassie-reject-all {
    background-color: var(--reject-all-button-background-color);
    border: 2px solid var(--reject-all-button-border-color);
    color: var(--reject-all-button-text-color);
    width: 164px;
    height: 47px;
}

.cassie-pre-banner .cassie-view-all {
    color: var(--view-all-button-text-color);
    background: #FFFFFF;
    border: 2px solid #3A3381;
    width: 192px;
    height: 47px;
    /*margin-top: 20px*/
}

.cassie-pre-banner .cassie-view-all:active {
    background: #D8D6E6;
    box-shadow: inset 0px 5px 6px #000000;
    border: 2px solid #3A3381;
    text-decoration: underline;
    color: #24285C;
}

.cassie-view-all--button--icon {
    fill: var(--prebanner-customise-all-button-text-color);
    fill: var(--view-all-button-icon-color);
    vertical-align: middle;
    display: none;
}

.cassie-gpc-pre-banner .cassie-gpc-pre-banner--text-container {
    color: var(--prebanner-text-color);
    margin: 15px 30px 0
}

.cassie-gpc-pre-banner--text-container .cassie-gpc-pre-banner-heading--text {
    text-align: center
}

.cassie-gpc-pre-banner--text-container .cassie-pre-banner--text {
    font-size: 12px;
    line-height: 1.6;
    padding: 30px 0;
    text-align: center
}

.cassie-gpc-pre-banner .cassie-gpc-accept-all, .cassie-gpc-pre-banner .cassie-gpc-back {
    background-color: var(--prebanner-background-color);
    border: 1px solid var(--prebanner-accept-all-button-color);
    color: var(--prebanner-accept-all-button-text-color)
}

.cassie-gpc-pre-banner .cassie-gpc-accept-all-excluding {
    background-color: var(--prebanner-accept-all-button-color);
    border: 1px solid var(--prebanner-accept-all-button-color);
    color: var(--prebanner-accept-all-button-text-color)
}

@media only screen and (max-width: 992px) {
    #cassie_pre_banner_text > h2 {
        margin-top: 2.4em;
        margin-bottom: 0.4em;
        font: normal normal normal 22px/27px Arial;
    }

    #cassie_pre_banner_text > p {
        margin-block-end: 0.4em;
        line-height: 1.4em;
    }

    /*#cassie_accept_all_pre_banner {
        width: 45%;
    }

    .cassie-pre-banner--button .cassie-view-all {
        width: 45%;
    }*/

    .cassie-cookie-module > .cassie-pre-banner {
        max-height: 95vh;
        overflow-y: auto;
        height: 80%;
    }

    .cassie-pre-banner--button--container .cassie-pre-banner--button {
        font-size: 12px;
    }
}

@media only screen and (max-width: 715px) {
    #cassie_pre_banner_text > h2 {
        margin-top: 0.4em;
        margin-bottom: 0.4em;
        font: normal normal normal 22px/27px Arial;
    }

    #cassie_pre_banner_text > p {
        margin-block-end: 0.4em;
        line-height: 1.4em;
    }

    /*#cassie_accept_all_pre_banner {
        width: 45%;
    }

    .cassie-pre-banner--button .cassie-view-all {
        width: 45%;
    }*/

    .cassie-cookie-module > .cassie-pre-banner {
        max-height: 95vh;
        overflow-y: auto;
        height: auto;

        flex-direction: row;

		bottom: 40px;
    }

    .cassie-pre-banner .cassie-pre-banner--button--container {
        display: inline-flex;
    }
}

@media only screen and (max-width: 480px) {
    /*#cassie_accept_all_pre_banner {
        width: 60%;
    }
    .cassie-pre-banner--button .cassie-view-all {
        width: 60%;
    }*/

    .cassie-pre-banner .cassie-pre-banner--button--container {
        display: block;
    }

    .cassie-cookie-modal--header--content > h2 {
        font: normal normal normal 22px/36px Arial;
    }
}

@media only screen and (max-width: 450px) {
    .cassie-cookie-modal--accept-all .cassie-cookie-modal--accept-all--text {
        display: flex;
    }

    .cassie-cookie-modal--group-head-container .cassie-cookie-group--description {
        width: 100% !important;
    }

    .cassie-cookie-modal--header--content > h2 {
        font: normal normal normal 25px/40px Arial;
    }
}

@media only screen and (min-width: 768px) {
    .cassie-cookie-module > .cassie-pre-banner {
        align-self: center;
        flex-wrap: nowrap;
        padding: 30px;
        margin: auto;
        height: auto;
    }

    .cassie-pre-banner .cassie-pre-banner--button--container {
        display: flex;
        flex-wrap: wrap;
        justify-content: left;
        margin: 0;
        width: 100%;
        padding: 0 30px;
    }

    .cassie-pre-banner--button--container .cassie-pre-banner--button {
      //  width: 168px;
       // height: 47px;
        margin-right:2%;
    }

    .cassie-gpc-pre-banner .cassie-gpc-pre-banner--text-container {
        margin-bottom: 40px;
        width: 60%;
    }

    .cassie-gpc-pre-banner--text-container .cassie-gpc-pre-banner-heading--text {
        text-align: left
    }

    .cassie-gpc-pre-banner--text-container .cassie-pre-banner--text {
        margin-bottom: 30px;
        padding: 0;
        text-align: left;
        width: 100%
    }

    .cassie-gpc-pre-banner .cassie-gpc-back {
        bottom: 20px;
        left: 0;
        margin-left: 30px;
        padding: 10px 0;
        position: absolute;
        width: 20%
    }
}

@media only screen and (min-width: 992px) {
    .cassie-cookie-module > .cassie-pre-banner {
        margin: auto;
    }

    .cassie-cookie-module .cassie-top {
        align-self: flex-start;
        border-radius: 0;
        flex-wrap: nowrap;
        margin: 0;
        padding: 0
    }

    .cassie-top .cassie-pre-banner--text {
        align-items: center;
        display: flex;
        margin: 0 0 0 10px;
        padding: 0;
        text-align: left;
        width: 50%
    }

    .cassie-top .cassie-pre-banner--button--container {
        flex-wrap: nowrap;
        justify-content: flex-end;
        width: 50%
    }

    .cassie-top .cassie-pre-banner--button {
        margin: 10px;
        width: 25%
    }

    .cassie-cookie-module .cassie-bottom {
        align-self: flex-end;
        border-radius: 0;
        flex-wrap: nowrap;
        margin: 0;
        padding: 0
    }

    .cassie-bottom .cassie-pre-banner--text {
        align-items: center;
        display: flex;
        margin: 0 0 0 10px;
        padding: 0;
        text-align: left;
        width: 50%
    }

    .cassie-bottom .cassie-pre-banner--button--container {
        flex-wrap: nowrap;
        justify-content: flex-end;
        width: 50%
    }

    .cassie-bottom .cassie-pre-banner--button {
        margin: 10px;
        width: 25%
    }

    .cassie-pre-banner .cassie-accept-all:hover, .cassie-pre-banner .cassie-reject-all:hover {
        background-color: #28245A;
        border: 2px solid #29245A;
        text-decoration: underline;
        cursor: pointer;
        opacity: 1;
        color: #fff;
    }

    .cassie-pre-banner .cassie-view-all:hover {
        background: #D8D6E6;
        border: 2px solid #3A3381;
        border-radius: 27px;
        color: #24285C;
        cursor: pointer;
        // padding: 1em;
        text-decoration: underline;
    }

    .cassie-gpc-pre-banner .cassie-gpc-back {
        bottom: 20px;
        left: 0;
        margin-left: 30px;
        max-width: 100px;
        padding: 10px 0;
        position: absolute
    }

    .cassie-cookie-module > .cassie-gpc-top {
        align-self: flex-start;
        border-radius: 0;
        margin: 0
    }

    .cassie-cookie-module > .cassie-gpc-bottom {
        align-self: flex-end;
        border-radius: 0;
        margin: 0
    }
}

@media only screen and (min-width: 1200px) {
    .cassie-cookie-module > .cassie-pre-banner {
        // margin: 0 27%
        width: 718px;
        height: 563px;
    }

    .cassie-cookie-module .cassie-top {
        margin: 0
    }

    .cassie-top .cassie-pre-banner--button {
        width: 20%
    }

    .cassie-cookie-module .cassie-bottom {
        margin: 0
    }

    .cassie-bottom .cassie-pre-banner--button {
        width: 20%
    }

    .cassie-cookie-module > .cassie-gpc-pre-banner {
        margin: 0 20%
    }

    .cassie-cookie-module > .cassie-gpc-bottom, .cassie-cookie-module > .cassie-gpc-top {
        margin: 0
    }
}

@media only screen and (min-width: 1600px) {
    .cassie-bottom .cassie-pre-banner--button, .cassie-top .cassie-pre-banner--button {
        width: 15%
    }

    .cassie-cookie-module > .cassie-gpc-bottom, .cassie-cookie-module > .cassie-gpc-top {
        margin: 0
    }
}

.cassie-cookie-module .cassie-cookie-modal::-webkit-scrollbar {
    width: 5px
}

.cassie-cookie-module .cassie-cookie-modal::-webkit-scrollbar-track {
    background-color: var(--banner-secondary-color);
    background-color: var(--scrollbar-background-color)
}

.cassie-cookie-module .cassie-cookie-modal::-webkit-scrollbar-thumb {
    background-color: var(--banner-text-color);
    background-color: var(--scrollbar-thumb-color)
}

.cassie-cookie-module .cassie-cookie-modal::-webkit-scrollbar-thumb:hover {
    background-color: var(--banner-submit-preferences-button-color);
    background-color: var(--scrollbar-thumb-hover-color)
}

.cassie-cookie-module .cassie-cookie-modal--right::-webkit-scrollbar {
    width: 5px
}

.cassie-cookie-module .cassie-cookie-modal--right::-webkit-scrollbar-track {
    background-color: var(--banner-secondary-color);
    background-color: var(--scrollbar-background-color)
}

.cassie-cookie-module .cassie-cookie-modal--right::-webkit-scrollbar-thumb {
    background-color: var(--banner-text-color);
    background-color: var(--scrollbar-thumb-color)
}

.cassie-cookie-module .cassie-cookie-modal--right::-webkit-scrollbar-thumb:hover {
    background-color: var(--banner-submit-preferences-button-color);
    background-color: var(--scrollbar-thumb-hover-color)
}

.cassie-cookie-module .cassie-cookie-modal--center::-webkit-scrollbar {
    width: 5px
}

.cassie-cookie-module .cassie-cookie-modal--center::-webkit-scrollbar-track {
    background-color: var(--banner-secondary-color);
    background-color: var(--scrollbar-background-color)
}

.cassie-cookie-module .cassie-cookie-modal--center::-webkit-scrollbar-thumb {
    background-color: var(--banner-text-color);
    background-color: var(--scrollbar-thumb-color)
}

.cassie-cookie-module .cassie-cookie-modal--center::-webkit-scrollbar-thumb:hover {
    background-color: var(--banner-submit-preferences-button-color);
    background-color: var(--scrollbar-thumb-hover-color)
}

.cassie-cookie-module > .cassie-cookie-modal {
    left: 0
}

.cassie-cookie-module > .cassie-cookie-modal, .cassie-cookie-module > .cassie-cookie-modal--right {
    right: 0
}

.cassie-cookie-module > .cassie-cookie-modal, .cassie-cookie-module > .cassie-cookie-modal--center, .cassie-cookie-module > .cassie-cookie-modal--right {
    background-color: var(--banner-background-color);
    background-color: var(--cookie-modal-background-color);
    bottom: 0;
    color: var(--banner-text-color);
    color: var(--cookie-modal-text-color);
    display: flex;
    flex-wrap: wrap;
    flex-flow: column;
    overflow: auto;
    overflow-x: hidden;
    overflow-y: scroll;
    -ms-overflow-y: scroll;
    padding: 20px;
    position: absolute;
    top: 0;
    z-index: 99999;
    margin: auto;
    max-width: 90%;
    width: fit-content;
    max-height:90%;
    height:85%;
    padding:20px 30px;
}

.cassie-cookie-modal--header {
    align-self: flex-start;
    display: flex;
    flex-shrink: 0;
    flex-wrap: wrap;
    width: 100%;
    border-bottom: 1px solid var(--cookie-group-bottom-border-colour);
}

.cassie-cookie-modal--header .cassie-cookie-modal--top-header {
    display: flex;
    justify-content: flex-end;
    width: 100%;
    height: 0px;
}

.cassie-cookie-modal--top-header > .cassie-cookie-modal--header-image {
    margin: 10px 0;
    max-width: 60%
}

.cassie-cookie-modal--header-image img {
    width: 100%
}

.cassie-cookie-modal--top-header .cassie-close-modal--container {
    display: none;
    justify-content: flex-end;
    width: 40%
}

.cassie-cookie-modal--top-header .cassie-close-modal-button {
    background-color: #2e2e37;
    background-color: var(--banner-background-color);
    border: none;
    color: var(--banner-secondary-color);
    color: var(--close-modal-button-color);
    cursor: pointer;
    font-size: 35px;
    font-weight: 600;
    height: 50px;
    line-height: 30px;
    margin-top: -20px;
    padding: 0 10px
}

.cassie-cookie-modal--header .cassie-cookie-modal--header--content {
    word-wrap: break-word;
    border-color: var(--banner-secondary-color) var(--header-content-top-border-color) var(--header-content-top-border-color);
    border-top: 2px solid;
    border-top-color: var(--header-content-top-border-color);
    font: normal normal normal 14px/18px Arial;
    color: #24285C;
    line-height: 1.6;
    margin: 0 0 10px;
    padding-top: 0px;
    width: 100%;
}

.cassie-cookie-modal--header > .cassie-cookie-modal--header--content {
    border: none !important;
}

.cassie-cookie-modal--header--content > h2 {
    opacity: 1;
    width: fit-content;
    text-align: left;
    letter-spacing: 0px;
    margin-bottom: 15px;
    font: normal normal normal 39px/46px Arial;
    color: #24285C;
}

.cassie-cookie-modal--header--content > p {
    font: normal normal normal 14px/18px Arial;
    color: #24285C;
}

.cassie-cookie-modal--header--content a {
    color: var(--banner-text-color);
    color: var(--cookie-modal-text-color)
}

.cassie-cookie-modal .cassie-cookie-modal--main {
    align-self: flex-start;
    border-color: currentcolor;
    border-color: var(--banner-secondary-color);
    border: 0px solid var(--main-content-border-colour);
    border-bottom: 0;
    display: flex;
    flex-shrink: 0;
    width: 100%
}

.cassie-cookie-modal--main > .cassie-cookie-modal--cookies--container {
    width: 100%
}

.cassie-cookie-modal--cookies--container > .cassie-cookie-modal--tabs--container {
    display: flex;
    width: 100%
}

.cassie-cookie-modal--tabs--container .cassie-tab--button {
    background-color: var(--banner-secondary-color);
    background-color: var(--tab-button-background-color);
    border-color: currentcolor;
    border-bottom: none;
    border-bottom-color: var(--banner-secondary-color);
    border-bottom: 2px solid var(--tab-button-border-color);
    border-left-color: var(--banner-secondary-color);
    border-right-color: var(--banner-secondary-color);
    border-top-color: var(--banner-secondary-color);
    border: var(--tab-button-border-color);
    color: var(--banner-text-color);
    color: var(--tab-button-text-color);
    cursor: pointer;
    font-size: 12px;
    height: 44px;
    width: 50%
}

.cassie-cookie-modal--tabs--container .cassie-active--button {
    border-left-color: var(--banner-text-color);
    border-color: var(--banner-text-color) var(--banner-text-color) var(--banner-text-color) var(--active-button-border-color);
    border-bottom: 2px solid;
    border-bottom-color: var(--active-button-border-color);
    border-right-color: var(--active-button-border-color);
    border-top-color: var(--active-button-border-color)
}

.cassie-cookie-modal--tab-group .cassie-cookie-modal--group {
    border-left-color: var(--banner-secondary-color);
    border-color: var(--banner-secondary-color) var(--banner-secondary-color) var(--banner-secondary-color) var(--cookie-group-bottom-border-colour);
    border-bottom: 1px solid;
    border-bottom-color: var(--cookie-group-bottom-border-colour);
    border-right-color: var(--cookie-group-bottom-border-colour);
    border-top-color: var(--cookie-group-bottom-border-colour);
    display: flex;
    flex-wrap: wrap
}

.cassie-cookie-modal--tab-group .cassie-cookie-modal--select--group {
    display: flex
}

.cassie-cookie-modal--tab-group .cassie-cookie-modal--group:nth-last-child(0) {
    border-bottom: none
}

.cassie-cookie-modal--group .cassie-cookie-modal--group-head-container {
    display: flex;
    flex-wrap: wrap;
    justify-content: space-between;
    padding: 10px;
    width: 100%;
    margin-left: -10px;
}

.cassie-expand-cookies--container .cassie-expand-cookies--icon {
    fill: var(--banner-submit-preferences-button-color);
    fill: var(--expand-cookies-icon-color)
}

.cassie-expand-cookies--container .cassie-expand-cookies--icon--open {
    -webkit-transform: scaleY(-1);
    transform: scaleY(-1)
}

.cassie-cookie-modal--group-head-container .cassie-expand-cookies--container {
    cursor: pointer;
    display: flex;
    padding: 10px 0 5px;
    width: 60%;
}

.cassie-expand-cookies--container .cassie-cookie-group--heading {
    font-size: 15px;
    line-height: 1.6;
    margin: 0 2px
}

.cassie-expand-cookies--icon {
    display: none;
}

.cassie-expand-cookies--container {
    pointer-events: none;
}

.cassie-cookie-modal--group-head-container .cassie-cookie-group--description {
    font: normal normal normal 14px/23px Arial;
    color: #24285C;
    line-height: 1.6;
    margin: 0 0 0px 0px;
    width: 75%
}

.cassie-strictly-necessary--description cassie-cookie-group--description {
    font: normal normal normal 14px/23px Arial;
    letter-spacing: 0px;
}

.cassie-cookie-modal--group .cassie-cookie-children--container {
    background-color: var(--banner-text-color);
    background-color: var(--cookie-children-container-background-color);
    color: var(--banner-secondary-color);
    color: var(--cookie-children-container-text-color);
    display: none;
    padding: 10px;
    transition: .2s linear;
    width: 100%
}

.cassie-cookie-modal--group .cassie-cookie-children--container--open {
    display: block;
    transition: .2s linear
}

.cassie-cookie-children--container > .cassie-cookie--child {
    display: flex;
    flex-wrap: wrap;
    justify-content: space-between;
    margin: 10px 0
}

.cassie-cookie--child > .cassie-cookie--child--heading {
    font-size: 12px;
    line-height: 1.6;
    margin: 0;
    width: 60%
}

.cassie-cookie--child--heading > .cassie-gpc-flag {
    background: var(--banner-submit-preferences-button-color);
    border-radius: 10px;
    color: var(--banner-submit-preferences-button-text-color);
    font-size: 8px;
    font-weight: 700;
    margin-left: 5px;
    padding: 2px 5px
}

.cassie-cookie--child .cassie-cookie--child--description {
    font-size: 12px;
    line-height: 1.6;
    margin: 5px 0;
    width: 75%
}

.cassie-cookie-modal--header .cassie-cookie-modal--accept-all {
    display: inline-block;
    margin: 10px 5px 20px 0px;
    width: 97%
}

.cassie-cookie-modal--accept-all .cassie-cookie-modal--accept-all--text {
    font: normal normal bold 17px/26px Arial;
}

.cassie-cookie-modal .cassie-toggle-switch {
    cursor: pointer;
    float: right;
    height: 24px;
    margin-left: 10px;
    position: relative;
    width: 50px
}

.cassie-cookie-modal .cassie-long-labels--parent {
    line-height: .8
}

.cassie-cookie-modal .cassie-toggle-switch:focus-within {
    outline: 3px solid #000
}

.cassie-cookie-modal .cassie-child-cookie--toggle-switch:focus-within {
    outline: 3px solid #fff
}

.cassie-cookie-modal .cassie-cookie-group--toggle-switch {
    margin-top: 10px
}

.cassie-cookie-modal .cassie-toggle-switch--status {
    font-size: 12px;
    position: relative;
    right: 50px;
    top: 2px
}

.cassie-cookie-modal .cassie-long-labels {
    right: 55px
}

.cassie-cookie-modal .cassie-toggle-switch--checkbox {
    bottom: 27px;
    cursor: pointer;
    height: 24px;
    opacity: 0;
    position: relative;
    right: 48px;
    width: 90px;
    z-index: 1
}

.cassie-cookie-modal .cassie-toggle-switch--slider {
    background-color: var(--slider-background-off);
    background-color: var(--slider-background-colour-unchecked);
    border-color: currentcolor;
    border-color: var(--slider-background-off);
    border: 1px solid var(--slider-background-colour-unchecked);
    border-radius: 34px;
    bottom: 0;
    cursor: pointer;
    left: 0;
    position: absolute;
    right: 7px;
    top: 0
}

.cassie-cookie-modal .cassie-toggle-switch--slider:before {
    background-color: var(--slider-toggle);
    background-color: var(--toggle-background-color);
    border-color: currentcolor;
    border-color: var(--slider-toggle);
    border: 1px solid var(--toggle-background-color);
    border-radius: 50%;
    bottom: 0;
    content: "";
    height: 20px;
    left: 0;
    position: absolute;
    -webkit-transition: .4s;
    transition: .4s;
    width: 20px
}

.cassie-cookie-modal .cassie-toggle-switch--slider--active {
    background-color: var(--slider-background-on);
    background-color: var(--slider-background-color-checked)
}

.cassie-cookie-modal .cassie-toggle-switch--slider--active:before {
    left: 21px
}

.cassie-cookie-modal--center .cassie-toggle-switch {
    cursor: pointer;
    float: right;
    height: 24px;
    left: 30px;
    position: relative;
    width: 60px
}

.cassie-cookie-modal--center .cassie-long-labels--parent {
    line-height: .8
}

.cassie-cookie-modal--center .cassie-toggle-switch:focus-within {
    outline: 3px solid #000
}

.cassie-cookie-modal--center .cassie-child-cookie--toggle-switch:focus-within {
    outline: 3px solid #fff
}

.cassie-cookie-modal--center .cassie-cookie-group--toggle-switch {
    margin-top: 10px
}

.cassie-cookie-modal--center .cassie-toggle-switch--status {
    //font-size: 12px;
    position: relative;
    right: 75px;
    width: 66px;
    font: normal normal normal 14px/21px Arial;
    display: block;
    /* top: 5px*/
}

.cassie-cookie-modal--center .cassie-long-labels {
    right: 55px
}

.cassie-cookie-modal--center .cassie-toggle-switch--checkbox {
    bottom: 27px;
    cursor: pointer;
    height: 24px;
    opacity: 0;
    position: relative;
    right: 48px;
    width: 90px;
    z-index: 1
}

.cassie-cookie-modal--center .cassie-toggle-switch--slider {
    background-color: var(--slider-background-off);
    background-color: var(--slider-background-colour-unchecked);
    border-color: currentcolor;
    border-color: var(--slider-background-off);
    border: 1px solid #1F55A5;
    border-radius: 100px;
    bottom: 0;
    cursor: pointer;
    left: 0;
    position: absolute;
    right: 7px;
    top: 0;
    height: 25px;
    width: 50px;
}

.cassie-cookie-modal--center .cassie-toggle-switch--slider:before {
    background-color: var(--slider-toggle);
    background-color: var(--toggle-background-color);
    border-radius: 50%;
    bottom: 2px;
    content: "";
    height: 19px;
    left: 2px;
    position: absolute;
    -webkit-transition: .4s;
    transition: .4s;
    width: 19px
}

.cassie-cookie-modal--center .cassie-toggle-switch--slider--active {
    background-color: var(--slider-background-on);
    background-color: var(--slider-background-color-checked)
}

.cassie-cookie-modal--center .cassie-toggle-switch--slider--active:before {
    left: 27px
}

.cassie-cookie-modal--right .cassie-toggle-switch {
    cursor: pointer;
    float: right;
    height: 24px;
    margin-left: 10px;
    position: relative;
    width: 50px
}

.cassie-cookie-modal--right .cassie-long-labels--parent {
    line-height: .8
}

.cassie-cookie-modal--right .cassie-toggle-switch:focus-within {
    outline: 3px solid #000
}

.cassie-cookie-modal--right .cassie-child-cookie--toggle-switch:focus-within {
    outline: 3px solid #fff
}

.cassie-cookie-modal--right .cassie-cookie-group--toggle-switch {
    margin-top: 10px
}

.cassie-cookie-modal--right .cassie-toggle-switch--status {
    font-size: 12px;
    position: relative;
    right: 50px;
    top: -2px
}

.cassie-cookie-modal--right .cassie-long-labels {
    right: 55px
}

.cassie-cookie-modal--right .cassie-toggle-switch--checkbox {
    bottom: 27px;
    cursor: pointer;
    height: 24px;
    opacity: 0;
    position: relative;
    right: 48px;
    width: 90px;
    z-index: 1
}

.cassie-cookie-modal--right .cassie-toggle-switch--slider {
    background-color: var(--banner-slider-background-off);
    background-color: var(--slider-background-colour-unchecked);
    border-color: currentcolor;
    border-color: var(--banner-slider-background-off);
    border: 1px solid var(--slider-background-colour-unchecked);
    border-radius: 34px;
    bottom: 0;
    cursor: pointer;
    left: 0;
    position: absolute;
    right: 7px;
    top: 0
}

.cassie-cookie-modal--right .cassie-toggle-switch--slider:before {
    background-color: var(--banner-slider-toggle);
    background-color: var(--toggle-background-color);
    border-radius: 50%;
    bottom: 2px;
    content: "";
    height: 20px;
    left: 2px;
    position: absolute;
    -webkit-transition: .4s;
    transition: .4s;
    width: 20px
}

.cassie-cookie-modal--right .cassie-toggle-switch--slider--active {
    background-color: var(--banner-slider-background-on);
    background-color: var(--slider-background-color-checked)
}

.cassie-cookie-modal--right .cassie-toggle-switch--slider--active:before {
    left: 21px
}

.cassie-accept-all--toggle-switch .cassie-accept-all--no-labels {
    bottom: 0
}

.cassie-cookie-group--toggle-switch .cassie-group--no-labels {
    bottom: 10px
}

.cassie-child-cookie--toggle-switch .cassie-child--no-labels {
    bottom: 5px
}

@media screen and (forced-colors:active) {
    .cassie-cookie-modal--center .cassie-toggle-switch--slider:before, .cassie-cookie-modal--right .cassie-toggle-switch--slider:before, .cassie-cookie-modal .cassie-toggle-switch--slider:before {
        background: windowText
    }
}

@media screen and (-ms-high-contrast:active) {
    .cassie-cookie-modal--center .cassie-toggle-switch--slider:before, .cassie-cookie-modal--right .cassie-toggle-switch--slider:before, .cassie-cookie-modal .cassie-toggle-switch--slider:before {
        background: windowText
    }
}

.cassie-cookie-modal .cassie-cookie-modal--footer {
    flex-shrink: 0;
    margin-top: auto;
    width: 100%
}

.cassie-cookie-modal--footer .cassie-cookie-modal--footer-content {
    font: normal normal normal 14px/18px Arial;
    color: #24285C;
    line-height: 1.6;
    width: 100%;
    margin-top: 2%;
}

.cassie-cookie-modal--footer-content a {
    color: var(--banner-text-color);
    color: var(--cookie-modal-text-color)
}

.cassie-cookie-modal--footer .cassie-cookie-modal--footer-extra {
    align-items: flex-end;
    display: flex;
    flex-wrap: nowrap;
    justify-content: space-between;
    width: 100%
}

.cassie-cookie-modal--footer-extra .cassie-cookie-modal--save-preferences--container {
    width: 40%
}

.cassie-cookie-modal--save-preferences--container .cassie-cookie-modal--save-preferences {
    background-color: var(--banner-submit-preferences-button-color);
    background-color: var(--save-preferences-button-background-color);
    border-color: currentcolor;
    border: 2px solid var(--save-preferences-button-border-color);
    border-radius: 27px;
    color: var(--banner-submit-preferences-button-text-color);
    color: var(--save-preferences-button-text-color);
    cursor: pointer;
    font-size: 12px;
    font-weight: 600;
    min-height: 47px;
    padding: 0 10px;
    width: 166px;
    font: normal normal normal 16px/18px Arial;
}

.cassie-cookie-modal--save-preferences--container .cassie-cookie-modal--save-preferences:hover {
    background: #28245A;
    border: 2px solid #29245A;
    opacity: 1;
    text-decoration: underline;
}

.cassie-cookie-modal--save-preferences--container .cassie-cookie-modal--save-preferences:focus {
    background: #FDF289;
    border: 2px solid #000;
    color: #000000;
}

.cassie-cookie-modal--save-preferences--container .cassie-cookie-modal--save-preferences:active {
    background: #28245A;
    box-shadow: inset 0px 5px 6px rgba(255,255,255,0.3);
    border: 2px solid #29245A;
    text-decoration: underline;
    color: #fff;
}

.cassie-cookie-modal--footer-extra .cassie-cookie-modal--footer-image--container {
    display: flex;
    /*justify-content: flex-end;*/
    padding: 10px 0;
    width: 60%;
    pointer-events: none;
}

.cassie-cookie-modal--footer-image--container .cassie-cookie-modal--footer-image {
    height: 28px;
    width: 97px
}

.cassie-cookie-modal--footer-image{
    display:none;
}

@media only screen and (min-width: 768px) {
    .cassie-cookie-module > .cassie-cookie-modal {
        border-bottom-color: var(--banner-submit-preferences-button-color);
        border-left-color: var(--banner-submit-preferences-button-color);
        border-color: var(--banner-submit-preferences-button-color) var(--banner-submit-preferences-button-color) var(--cookie-modal-border-color) var(--cookie-modal-border-color);
        border-right: 1px solid;
        border-right-color: var(--cookie-modal-border-color);
        border-top-color: var(--cookie-modal-border-color);
        width: 60%
    }

    .cassie-cookie-module > .cassie-cookie-modal--right {
        border-left: 15px solid;
        border-color: var(--cookie-modal-border-color);
        border-right: none;
        left: unset;
        width: 60%
    }

    .cassie-cookie-module > .cassie-cookie-modal--center {
        align-self: center;
        bottom: unset;
        box-shadow: 0 0 60px 10px rgba(0,0,0,.6);
        margin: 0 15%;
        top: unset;
        width: 60%;
        max-height: 90%;
        height: auto;
    }

    .cassie-cookie-modal--top-header .cassie-cookie-modal--header-image {
        max-width: 50%
    }

    .cassie-cookie-modal--top-header .cassie-close-modal--container {
        width: 50%
    }
}

@media only screen and (min-width: 992px) {
    .cassie-cookie-module > .cassie-cookie-modal, .cassie-cookie-module > .cassie-cookie-modal--right {
        width: 35%
    }

    .cassie-cookie-module > .cassie-cookie-modal--center {
        max-height: 90%;
        margin: 0 25%;
        width: 50%;
        height: auto;
    }
}

@media only screen and (min-width: 1200px) {
    .cassie-cookie-module > .cassie-cookie-modal, .cassie-cookie-module > .cassie-cookie-modal--right {
        width: 25%
    }

    .cassie-cookie-module > .cassie-cookie-modal--center {
        //margin: 0 30%;
        //width: 40%
        width: 960px;
        height: 752px;
        margin: auto;
    }
}

@media only screen and (min-width: 1500px) {
    .cassie-cookie-module > .cassie-cookie-modal, .cassie-cookie-module > .cassie-cookie-modal--right {
        width: 20%
    }

    .cassie-cookie-module > .cassie-cookie-modal--center {
        height: 70%;
        margin: 0 35%;
        width: 30%
    }
}

#cassie-widget > .cassie-manage-cookies--container {
    bottom: 0;
    margin: 10px;
    position: fixed;
    z-index: 9999
}

.cassie-manage-cookies--container > .cassie-manage-cookies--button {
    background-color: var(--banner-submit-preferences-button-color);
    background-color: var(--manage-cookies-button-background-color);
    border-color: currentcolor;
    border-left: none;
    border-radius: 15px;
    border-right: none;
    border-color: var(--banner-submit-preferences-button-color);
    border-bottom: var(--manage-cookies-button-border-color);
    border-left: 15px solid var(--manage-cookies-button-border-color);
    border-right: 15px solid var(--manage-cookies-button-border-color);
    border-top-color: var(--banner-submit-preferences-button-color);
    border-top: var(--manage-cookies-button-border-color);
    color: var(--banner-submit-preferences-button-text-color);
    color: var(--manage-cookies-button-text-color);
    cursor: pointer;
    min-height: 44px;
    padding: 0 10px;
    transition: .2s linear
}

.cassie-manage-cookies--container .cassie-manage-cookies--button:focus {
    outline: 3px solid #000;
    outline-offset: 2px
}

.cassie-manage-cookies--container .cassie-manage-cookies--button--text {
    display: none
}

@media only screen and (min-width: 992px) {
    .cassie-manage-cookies--container .cassie-manage-cookies--button {
        margin-bottom: -15px;
        min-width: 150px
    }

    .cassie-manage-cookies--container .cassie-manage-cookies--button:hover {
        margin-bottom: 0 !important
    }

    .cassie-manage-cookies--container .cassie-arrow-down--hover {
        border-left: 10px solid transparent;
        border-right: 10px solid transparent;
        border-top: 10px solid red;
        border-top: 10px solid var(--banner-submit-preferences-button-color);
        height: 0;
        margin: 0 auto;
        width: 0
    }
}

.cassie-d-none {
    display: none
}

.cassie-d-none-important {
    display: none !important
}

.cassie-d-block {
    display: block
}

.cassie-d-flex {
    display: flex
}

@-moz-document url-prefix() {
    .cassie-pre-banner--text > h2 {
        width: max-content;
    }

    .cassie-pre-banner .cassie-pre-banner--text {
        width: 90%;
    }

    @media only screen and (max-width: 480px) {
        .cassie-pre-banner--button--container .cassie-pre-banner--button {
            margin-left: 5%;
            width: 65%
        }
    }
}