@import "variables.less";
@import "mixins.less";
@import "base.less";

/*! normalize.css v2.1.3 | MIT License | git.io/normalize */

// Correct `block` display not defined in IE 8/9.
body {
    //color: #424242;
	//background-color: #fff;
	//text-rendering: optimizeLegibility;
	//-webkit-font-smoothing: antialiased;
	//font-weight: normal;
	//font-size:1em;
	//font-family:"futura-pt", verdana, sans-serif;
    margin: 0;
	padding: 0;
	border: 0;
}

.ou-cookies-bar,
#ou-header,
.ou-footer {
    // Base
    font-family: @base-font-family; // 1
    -ms-text-size-adjust: 100%; // 2
    -webkit-text-size-adjust: 100%; // 2
     text-rendering: optimizeLegibility;
    // Remove default margin.
    margin: 0;
    font-size: @base-font-size-legacy;
    font-size: @base-font-size;
    line-height: @base-line-height;
    footer,
    header,
    main,
    nav,
    section {
        display: block;
    }
    p, ul, ol, dl {
        line-height: @base-line-height;
    }
    // Correct `inline-block` display not defined in IE 8/9.


    // Links
    // Remove the gray background color from active links in IE 10.
    a {
        background: transparent;
        //  Address `outline` inconsistency between Chrome and other browsers.
        //&:focus {
        //    outline: thin dotted;
        //}
        // Improve readability when focused and also mouse hovered in all browsers.
        //&:active,
        //&:hover {
        //        outline: 0;
        //}
    }

    // Typography

    // Address variable `h1` font-size and margin within `section` and `article`
    // contexts in Firefox 4+, Safari 5, and Chrome.
    //h1 {
    //    font-size: @h1-font-size;
    //    margin: 0.67em 0;
    //}
    //h2 {
    //    font-size: @h2-font-size;
    //}
    h3 {
        font-size: @h3-font-size;
        line-height: normal;
    }
    h4 {
        font-size: @h4-font-size;
    }
    //h5 {
    //    font-size: @h5-font-size;
    //}
    //h6 {
    //    font-size: @h6-font-size;
    //}

    // Address differences between Firefox and other browsers.

    hr {
        -moz-box-sizing: content-box;
        -webkit-box-sizing: content-box;
        box-sizing: content-box;
        height: 0;
    }

    // 1. Correct font family not being inherited in all browsers.
    // 2. Correct font size not being inherited in all browsers.
    // 3. Address margins set differently in Firefox 4+, Safari 5, and Chrome.

    button,
    input,
    select,
    textarea {
        font-family: inherit; // 1
        font-size: 100%; // 2
        margin: 0; // 3
    }

    // Address Firefox 4+ setting `line-height` on `input` using `!important` in
    // the UA stylesheet.

    button,
    input {
        line-height: normal;
    }

    // Address inconsistent `text-transform` inheritance for `button` and `select`.
    // All other form control elements do not inherit `text-transform` values.
    // Correct `button` style inheritance in Chrome, Safari 5+, and IE 8+.
    // Correct `select` style inheritance in Firefox 4+ and Opera.

    button,
    select {
        text-transform: none;
    }

    // 1. Avoid the WebKit bug in Android 4.0.* where (2) destroys native `audio`
    //    and `video` controls.
    // 2. Correct inability to style clickable `input` types in iOS.
    // 3. Improve usability and consistency of cursor style between image-type
    //    `input` and others.

    button,
    html input[type="button"], // 1
    input[type="reset"],
    input[type="submit"] {
        -webkit-appearance: button; // 2
        cursor: pointer; // 3
    }

    // 1. Address `appearance` set to `searchfield` in Safari 5 and Chrome.
    // 2. Address `box-sizing` set to `border-box` in Safari 5 and Chrome
    //    (include `-moz` to future-proof).

    input[type="search"] {
        -webkit-appearance: textfield; // 1
        -moz-box-sizing: content-box;
        -webkit-box-sizing: content-box; // 2
        box-sizing: content-box;
    }

    // Remove inner padding and border in Firefox 4+.

    button::-moz-focus-inner,
    input::-moz-focus-inner {
        border: 0;
        padding: 0;
    }

}

// Clears

// Change from *

#i-cookies-bar *,
#ou-head #ou-header *,
#ou-head #ou-header *:before,
#ou-head #ou-header *:after,
#ou-org-footer *,
#ou-org-footer *:before,
#ou-org-footer *:after {
    .boxSizing();
}

#ou-header,
#ou-site, //For OUICE
#ou-footer
{
    zoom: 1; // For IE 6/7 (trigger hasLayout)
}

#ou-header:before, div#ou-header:after,
#ou-site:before, div#ou-site:after, // for OUICE
#ou-footer:before, #ou-footer:after
{
    content: "";
    display: table;
    line-height: 0;
}

#ou-header:after,
#ou-site:after, // for OUICE
#ou-footer:after
{
    clear: both;
}


// OUDigital overides
.generatedcontent {
    #ou-header, .ou-footer, #country_selection_dialog, .accounts-tab-nav {
        ul li {
            position: inherit;
            padding: 0 0 0 1px;

            &:before {
                content: "";
                display: block;
            }
        }
    }

    ul.ui-tabs-nav li {
        &:extend(.generatedcontent #ou-head #ou-header ul li);

        &:before {
            &:extend(.generatedcontent #ou-head #ou-header ul li:before);
        }
    }
}
// Postgrad OUICE/EEP overides - to be moved in to Postgrad site
.generatedcontent body.ou-postgrad-ouice #ou-head #ou-header ul li:before {
    content: none;
}
.generatedcontent body.ou-postgrad-ouice #ou-head #ou-header ul li.ou-search:before {
    content: "";
}
body.ou-postgrad-ouice {
    .ou-contact {
        background: transparent;
        box-shadow: none;
        border-top: 0;
        border-left: 0;
        border-right: 0;
        padding-bottom: 0;
        padding-left: 0;
        padding-right: 0;
        margin-top: 0;
    }
    div#ou-org-footer.ou-footer {
        padding: 20px 0;
        margin-top: 1em;
        ul, li {
            margin: 0;
            padding: 0;
        }
    }
    .country-changer
    {
        padding: 1em 0 0 0;
    }
}

