.ou-cookies-bar, .int-ouFooter, .ou-skip, .ou-identity, .ou-mobile-menu-toggle, #ou-header-nav {
    display:none;
}
#ou-header a.ou-logo {
    float: right;
    display: block;
    margin: 0 0.5cm 0 0;
 /*   height: 61px;
    width: 87px;*/
    overflow: hidden;
    height: 57px;
    width: 82px;
    background-image: url('/ouheaders/gui/England.svg?2.0.0.542');
    background-size: 82px 57px;
    position: relative;
}
#ou-header a.ou-logo.england,
.scotland #ou-header a.ou-logo.scotland,
.wales #ou-header a.ou-logo.wales,
.cymraeg #ou-header a.ou-logo.cymraeg,
.roi #ou-header a.ou-logo.roi,
.nir #ou-header a.ou-logo.nir,
.ou-ia-international #ou-header a.ou-logo.international,
.ou-ia-nonav #ou-header a.ou-logo.nonav {
    display: block;
    visibility: visible;
}
#ou-header a.ou-logo img {
    border: 0;
    position: relative;
    width: 258px !important;
    display: block !important;
    max-width: none !important;
}

#ou-header a.ou-logo.international,
#ou-header a.ou-logo.scotland,
#ou-header a.ou-logo.nir,
#ou-header a.ou-logo.roi,
#ou-header a.ou-logo.wales,
#ou-header a.ou-logo.cymraeg,
#ou-header a.ou-logo.nonav,
.scotland #ou-header a.ou-logo.england,
.scotland #ou-header a.ou-logo.nir,
.scotland #ou-header a.ou-logo.roi,
.scotland #ou-header a.ou-logo.wales,
.scotland #ou-header a.ou-logo.cymraeg,
.scotland #ou-header a.ou-logo.nonav,
.wales #ou-header a.ou-logo.england,
.wales #ou-header a.ou-logo.scotland,
.wales #ou-header a.ou-logo.nir,
.wales #ou-header a.ou-logo.roi,
.wales #ou-header a.ou-logo.cymraeg,
.wales #ou-header a.ou-logo.nonav,
.cymraeg #ou-header a.ou-logo.england,
.cymraeg #ou-header a.ou-logo.scotland,
.cymraeg #ou-header a.ou-logo.nir,
.cymraeg #ou-header a.ou-logo.roi,
.cymraeg #ou-header a.ou-logo.wales,
.cymraeg #ou-header a.ou-logo.nonav,
.roi #ou-header a.ou-logo.england,
.roi #ou-header a.ou-logo.scotland,
.roi #ou-header a.ou-logo.nir,
.roi #ou-header a.ou-logo.wales,
.roi #ou-header a.ou-logo.cymraeg,
.roi #ou-header a.ou-logo.nonav,
.nir #ou-header a.ou-logo.england,
.nir #ou-header a.ou-logo.scotland,
.nir #ou-header a.ou-logo.roi,
.nir #ou-header a.ou-logo.wales,
.nir #ou-header a.ou-logo.cymraeg,
.nir #ou-header a.ou-logo.nonav,
.ou-ia-international #ou-header a.ou-logo.england,
.ou-ia-international #ou-header a.ou-logo.nir,
.ou-ia-international #ou-header a.ou-logo.roi,
.ou-ia-international #ou-header a.ou-logo.wales,
.ou-ia-international #ou-header a.ou-logo.cymraeg,
.ou-ia-international #ou-header a.ou-logo.scotland,
.ou-ia-international #ou-header a.ou-logo.nonav,
.ou-ia-nonav #ou-header a.ou-logo.england,
.ou-ia-nonav #ou-header a.ou-logo.scotland,
.ou-ia-nonav #ou-header a.ou-logo.nir,
.ou-ia-nonav #ou-header a.ou-logo.roi,
.ou-ia-nonav #ou-header a.ou-logo.wales,
.ou-ia-nonav #ou-header a.ou-logo.cymraeg,
.ou-ia-nonav #ou-header a.ou-logo.international
 {
    visibility: hidden;
    display: none;
}
/*Scotland*/
.scotland #ou-header a.ou-logo {
/*    width: 83px;
    height: 76px;*/
    height: 75px;
    width: 82px;
    background-image: url('/ouheaders/gui/Scotland.svg?2.0.0.542');
    background-size: 82px 75px;
    position: relative;
}
.scotland #ou-header a.ou-logo.scotland img {
   /* top: -69px;*/
    position: relative;
    display: block;
}
/*Wales*/
.wales #ou-header a.ou-logo, .cymraeg #ou-header a.ou-logo {
    /*width: 107px;
    height: 78px;*/
    height: 75px;
    width: 106px;
    background-image: url('/ouheaders/gui/Wales.svg?2.0.0.542');
    background-size: 106px 75px;
    position: relative;
}
.wales #ou-header a.ou-logo.wales img, .cymraeg #ou-header a.ou-logo.cymraeg img {
    /*top: -150px;*/
    position: relative;
}
/*ROI*/
.roi #ou-header a.ou-logo {
   /* width: 83px;
    height: 75px;*/
    height: 75px;
    width: 82px;
    background-image: url('/ouheaders/gui/Ireland.svg?2.0.0.542');
    background-size: 82px 75px;
    position: relative;
}
.roi #ou-header a.ou-logo.roi img {
   /* top: -320px;
    left: -176px;*/
    position: relative;
    display: block;
}
/*Footer*/
#ou-site-footer {
    background: none;
    padding: 0;
}
body .ou-footer .ou-header, body .ou-footer #ou-ia-public, body .ou-footer #ou-ia-student, .int-notice.int-notice-icon.int-notice-icon-prospectus {
    display: none;
    visibility: hidden;
}
.ou-footer .ou-small-print {
    padding: 0;
}
.ou-footer .ou-copyright {
    color: #424242;
    padding: 0;
    margin: 0 0.5cm;
}
body .ou-footer .ou-small-print .ou-copyright small {
    font-size: 11pt !important;
}